More about LilyPond
===================

Abjad extends LilyPond
----------------------

`LilyPond`_ is an open-source music notation package
invented by Han-Wen Nienhuys and Jan Niewenhuizen and extended by an
international team of developers and musicians. LilyPond differs from other
music engraving programs in a number of ways. LilyPond separates musical
content from page layout. LilyPond affords typographic control over almost
everything. And LilyPond implements a powerfully correct model of the musical
score.

You can start working with Abjad right away because Abjad creates LilyPond
files for you automatically. But you will work with Abjad faster and more
effectively if you understand the structure of the LilyPond files Abjad
creates. For this reason we recommend new users spend a couple of days
learning LilyPond first.

Start by reading about `text input <http://lilypond.org/text-input.html>`_ in
LilyPond. Then work through the `LilyPond tutorial
<http://www.lilypond.org/doc/v2.19/Documentation/learning/tutorial>`_. You can
test your understanding of LilyPond by using the program to engrave the first
few phrases of a Bach chorale. Once you can engrave a chorale in LilyPond
you'll understand the way Abjad works with LilyPond behind the scenes.

..  _LilyPond: http://lilypond.org/
